@@ -45,8 +45,12 @@ if (getRversion() >= "3.1.0") {
       "end_date",
       "weekday",
       "exception_type",
-      "arrival_time_hms",
-      "departure_time_hms"
+      "arrival_time",
+      "departure_time",
+      "start_time",
+      "end_time",
+      "feed_start_date",
+      "feed_end_date"
     )
   )
 }
\ No newline at end of file
