@@ -16,7 +16,7 @@
 #' @examples
 #' local_gtfs_path <- system.file("extdata", "google_transit_nyc_subway.zip", package = "tidytransit")
 #' gtfs <- read_gtfs(local_gtfs_path)
-#' names(gtfs)
+#' summary(gtfs)
 #'
 #' gtfs <- read_gtfs(local_gtfs_path, files = c("trips", "stop_times"))
 #' names(gtfs)
@@ -27,7 +27,7 @@ read_gtfs <- function(path, files = NULL, quiet = TRUE) {
   g = gtfsio::import_gtfs(path, files = files, quiet = quiet)
   
   # validate
-  validation_result <- validate_gtfs(g)
+  validation_result <- validate_gtfs(g, files = files, quiet = quiet)
   
   # prep tidygtfs columns
   g$. <- list()
@@ -47,7 +47,8 @@ read_gtfs <- function(path, files = NULL, quiet = TRUE) {
 #' Write a tidygtfs object to a zip file
 #' 
 #' @note Auxilliary tidytransit tables (e.g. \code{dates_services}) are not exported.
-#' @param gtfs_obj a tidygtfs object
+#' 
+#' @param gtfs_obj gtfs feed (tidygtfs object)
 #' @param zipfile path to the zip file the feed should be written to
 #' @param compression_level a number between 1 and 9.9, passed to zip::zip
 #' @param as_dir if TRUE, the feed is not zipped and zipfile is used as a directory path. 
